@@ -1,13 +1,12 @@
 package Tcl::pTk;
 
-our ($VERSION) = ('1.08_02');
+our ($VERSION) = ('1.01');
 
 use strict;
 use Tcl;
 use Exporter ('import');
 use Scalar::Util (qw /blessed/); # Used only for its blessed function
 use AutoLoader; # Used for autoloading the Error routine
-use Time::HiRes; # Used for emulating timeofday()
 use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS $platform @cleanup_refs $cleanup_queue_maxsize $cleanupPending);
 
 # Wait till we have 100 things to delete before we do cleanup
@@ -18,8 +17,6 @@ BEGIN{
  if($^O eq 'cygwin')
   {
    $platform = 'MSWin32'
-   # could still be set to 'unix' once Tcl is loaded
-   # depending on $::tcl_platform(platform)
   }
  else
   {
@@ -71,11 +68,6 @@ if($DEBUG){
         import Sub::Name;
 }
 
-# Variable to indicate whether Tile/Ttk widgets are available
-our ( $_Tile_available );
-# Variable to indicate whether Tcl/Tk 8.5.9 or later, or Tile 0.8.4.0
-# for Tcl/Tk 8.4, is available; needed by certain features
-our ( $_Tile_ge_0840 );
 
 @Tcl::pTk::ISA = qw(Tcl);
 
@@ -258,7 +250,7 @@ B<Perl/Tk compatible syntax:>
 
 B<Tcl::pTk Syntax:>
 
-  $int->MainLoop;
+  $inst->MainLoop;
 
 =head2 Creating and using widgets
 
@@ -336,8 +328,7 @@ interpreter.
 
 =head3 Perl/Tk syntax
 
-C<Tcl::pTk> fully supports perl/Tk widget syntax of the L<Tk> package,
-which has been used for many years. This means that any C<Tcl::pTk> widget
+C<Tcl::pTk> fully supports perl/Tk widget syntax of the L<Tk> package, which has been used for many years. This means that any C<Tcl::pTk> widget
 has a number of methods like C<Button>, C<Frame>, C<Text>, C<Canvas> and so
 on, and invoking those methods will create an appropriate child widget.
 C<Tcl::pTk> will generate an unique path-name for a newly created widget.
@@ -382,8 +373,7 @@ compatibile with the perl/Tk syntax. Examples of this type of widget are the Tex
 =item Megawidgets
 
 These are widgets that are composed of one-or-more other base widget types. Pure-perl megawidgets are supported in Tcl::pTk,
-just like they are in perl/Tk. Examples of these types of widgets are ProgressBar, LabEntry, BrowseEntry, and SlideSwitch
-(one of the test cases in the source distribution).
+just like they are in perl/Tk. Examples of these types of widgets are ProgressBar, LabEntry, BrowseEntry, and SlideSwitch (one of the test cases in the source distribution).
 
 =item Derived Widgets
 
@@ -598,8 +588,8 @@ You can also intermix the perl/tk and Tcl/Tk syntax like this:
 
 For the documentation of standard perl/tk widgets (like Button, Entry, Menu, etc), you can refer
 to the the perl/tk docs L<Tk> (We may move a copy of the perl/tk docs to Tcl::pTk in the future). For non-standard
-widgets (like the BLTNotebook widget example above) you have to use the Tcl docs on the widget for the widget documentation.
-(Most Tcl/Tk docs can be found at http://www.tcl.tk/ )
+widgets (like the BLTNotebook widget example above) you have to use the Tcl docs on the widget for the widget documentation. (Most Tcl/Tk
+docs can be found at http://www.tcl.tk/ )
 
 When reading Tcl/Tk widget documentation about widgets, you can apply the following guidelines to determine how
 to use the widget in C<Tcl::pTk> using perl/tk syntax.
@@ -681,8 +671,8 @@ and widget-elements.
 
 =head1 Terminology
 
-In the documentation and comments for this package, I<perl/Tk>, I<Tcl/Tk>, I<Tcl::pTk>, I<Tcl.pm>, and I<Tcl> are used.
-These terms have the following meanings in the context of this package.
+In the documentation and comments for this package, I<perl/Tk>, I<Tcl/Tk>, I<Tcl::pTk>, I<Tcl.pm>, and I<Tcl> are used. These terms have the
+following meanings in the context of this package.
 
 =over 1
 
@@ -832,11 +822,6 @@ sub new {
     # Create background error handling method that is similar to the way perltk does it
     $tkinterp->CreateCommand('bgerror', \&Tcl::pTk::bgerror);
 
-    # correct $platform: if we're on 'cygwin' but tcl/tk is on 'unix', then platform is 'unix':
-    if($^O eq 'cygwin' && $i->GetVar2('tcl_platform','platform') eq 'unix') {
-        $platform = 'unix';
-    }
-
     # RT #127120: Middle-click paste workaround
     # for older Tcl/Tk versions on macOS aqua
     if ($i->Eval('tk windowingsystem') eq 'aqua') {
@@ -877,17 +862,10 @@ sub tkinit {
 sub MainWindow {
     my $interp = Tcl::pTk->new(@_);
 
-    # Load Tile Widgets if Tile package is present
-    # (included in Tcl/Tk 8.5+, or as an extension for Tcl/Tk 8.4)
-    $Tcl::pTk::_Tile_available = $interp->pkg_require('tile');
-    if ($Tcl::pTk::_Tile_available) {
-        # Certain features require Tcl/Tk 8.5.9 or later,
-        # or Tile 0.8.4.0 for Tcl/Tk 8.4
-        $Tcl::pTk::_Tile_ge_0840 = ($interp->Eval(
-            "package vcompare $Tcl::pTk::_Tile_available 0.8.4.0"
-        ) != -1);
-        require Tcl::pTk::Tile;
-        Tcl::pTk::Tile::_declareTileWidgets($interp);
+    # Load Tile Widgets, if the tcl version is >= 8.5
+    if( $interp->Eval('package vsatisfies [package provide Tk] 8.5') ){
+            require Tcl::pTk::Tile;
+            Tcl::pTk::Tile::_declareTileWidgets($interp);
     }
     
     # Load palette commands, so $interp->invoke can be used with them later, for speed.
@@ -931,7 +909,12 @@ sub MainLoop {
 }
 
 # timeofday function for compatibility with Tk::timeofday
-*Tcl::pTk::timeofday = \&Time::HiRes::time;
+sub timeofday {
+    my $int = (ref $_[0]?shift:$tkinterp);
+    my $t = $int->invoke("clock", "microseconds");
+    $t = $t/1e6;
+}
+
 
 # DoOneEvent for compatibility with perl/tk
 sub DoOneEvent{
@@ -948,19 +931,23 @@ sub after{
     my $callback = shift;
     
     $ms = int($ms) if( $ms =~ /\d/ ); # Make into an integer to keep tk from complaining
-
-    # If no Callback defined, just do a sleep
-    return $int->call('after', $ms) unless defined($callback);
-
-    # Turn into callback, if not one already
-    unless( blessed($callback) and $callback->isa('Tcl::pTk::Callback')){
-        $callback = Tcl::pTk::Callback->new($callback);
+    
+    if( defined($callback)){
+            # Turn into callback, if not one already
+            unless( blessed($callback) and $callback->isa('Tcl::pTk::Callback')){
+                    $callback = Tcl::pTk::Callback->new($callback);
+            }
+            
+            my $sub = sub{ $callback->Call()};
+            #print "Tcl::pTk::after: setting after on $sub\n";
+            my $ret = $int->call('after', $ms, $sub );
+            return $int->declare_widget($ret);
     }
-
-    my $sub = sub{ $callback->Call()};
-    #print "Tcl::pTk::after: setting after on $sub\n";
-    my $ret = $int->call('after', $ms, $sub );
-    return $int->declare_widget($ret);
+    else{ # No Callback defined, just do a sleep
+            return $int->call('after', $ms );
+    }
+    
+    return($int->call('after', $ms));
 }
 
 
@@ -1077,7 +1064,7 @@ sub widget_deletion_watcher {
 }
 
 ###############################################
-#  Overridden delete_ref
+#  Overriden delete_ref
 #  Instead of immediately deleting a scalar or code ref in Tcl-land,
 #   queue the ref to be deleted in an after-idle call.
 #   This is done, rather than deleting immediately, because an immediate delete
@@ -1212,6 +1199,26 @@ sub pkg_require {
     return $preloaded_tk{$id};
 }
 
+sub need_tk {
+    # DEPRECATED: Use pkg_require and call instead.
+    my $int = shift;
+    my $pkg = shift;
+    my $cmd = shift || '';
+    warn "DEPRECATED CALL: need_tk($pkg, $cmd), use pkg_require\n";
+    if ($pkg eq 'ptk-Table') {
+        require Tcl::pTk::Table;
+    }
+    else {
+	# Only require the actual package once
+	my $ver = $int->pkg_require($pkg);
+	return 0 if !defined($ver);
+	$int->Eval($cmd) if $cmd;
+    }
+    return 1;
+}
+
+
+
 # subroutine findINC copied from perlTk/Tk.pm
 sub findINC {
     my $file = join('/',@_);                 # Normal location
@@ -1442,7 +1449,7 @@ sub bgerror{
 #   own functions here that previously were provided with Tcl.pm <= 1.02
 #############################################################################################
 ###############################################
-#  Overridden delete_widget_refs
+#  Overriden delete_widget_refs
 #  This is implemented in Tcl::pTk.pm because for versions of Tcl.pm > 1.02,
 #  this method is not supported, so we implement it ourselves here.
 sub delete_widget_refs {
@@ -1470,7 +1477,7 @@ sub _delete_ref {
     return $ref;
 }
 ###############################################
-#  Overridden _current_refs_widget
+#  Overriden _current_refs_widget
 #  This is implemented in Tcl::pTk.pm because for versions of Tcl.pm > 1.02,
 #  this method is not supported, so we implement it ourselves here.
 sub _current_refs_widget {$current_widget=shift}
@@ -1626,7 +1633,28 @@ sub call {
     # A SvIV will become a Tcl_IntObj, ARRAY refs will become Tcl_ListObjs,
     # and so on.  The return result from icall will do the opposite,
     # converting a Tcl_Obj to an SV.
-    return $interp->icall(@args);
+    if (!$Tcl::STACK_TRACE) {
+	return $interp->icall(@args);
+    }
+    elsif (wantarray) {
+	my @res;
+	eval { @res = $interp->icall(@args); };
+	if ($@) {
+	    require Carp;
+	    Carp::confess ("Tcl error '$@' while invoking array result call:\n" .
+		"\t\"@args\"");
+	}
+	return @res;
+    } else {
+	my $res;
+	eval { $res = $interp->icall(@args); };
+	if ($@) {
+	    require Carp;
+	    Carp::confess ("Tcl error '$@' while invoking scalar result call:\n" .
+		"\t\"@args\"");
+	}
+	return $res;
+    }
 }
 
 #############################################################################################
