@@ -6,10 +6,7 @@
 
 package Tcl::pTk::After;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Carp;
 
