@@ -1,9 +1,6 @@
 package Tcl::pTk::Bitmap;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 require Tcl::pTk;
 require Tcl::pTk::Image;
