@@ -2,12 +2,10 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tcl::pTk::Clipboard;
-
-our ($VERSION) = ('1.08_02');
-
-use warnings;
 use strict;
 
+our ($VERSION) = ('1.01');
+
 use Tcl::pTk;
 
 sub clipEvents
