@@ -1,9 +1,9 @@
+use strict;
+
+
 package Tcl::pTk::Entry;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 # Entry widget is all auto-wrapped. 
 # This File primarily needed to keep from getting the double-paste problem seen, where pasting into an
