@@ -1,9 +1,6 @@
 package Tcl::pTk::ErrorDialog;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk ();
 require Tcl::pTk::Dialog;
@@ -16,6 +13,8 @@ use vars ( qw/ $ED_OBJECT /);
 # module if you want them in a window.  You can also "roll your own" by
 # supplying the routine Tcl::pTk::Error.
 
+use strict;
+
 Construct Tcl::pTk::Widget 'ErrorDialog';
 
 my %options = ( -buttons => ['OK', 'Skip Messages', 'Stack trace'],
