@@ -1,9 +1,6 @@
 package Tcl::pTk::MainWindow;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk::Toplevel;
 
