@@ -1,6 +1,6 @@
 package Tcl::pTk::Menu;
 
-our ($VERSION) = ('1.08_02');
+our ($VERSION) = ('1.01');
 
 # Simple Menu package.
 #  This file is needed to provide the proper inheritance of Menu to 
@@ -221,8 +221,7 @@ sub Tcl::pTk::Menu {
            shift;
            $wpref = shift;
            $wpref = lcfirst $wpref; # window name must start with a lower case letter in tcl 
-           $wpref =~ s/[\s\.]+/_/g; # no spaces or '.' allowed in window names in tcl
-                                    # https://rt.cpan.org/Ticket/Display.html?id=125058
+           $wpref =~ s/\s+/_/g; # no spaces allowed in window names in tcl
    }
 
     my $w    = $self->w_uniq($wpref); # return unique widget id
