@@ -7,10 +7,7 @@
 
 package Tcl::pTk::Optionmenu;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk;
 require Tcl::pTk::Menubutton;
@@ -20,6 +17,8 @@ use Carp;
 
 use base  qw(Tcl::pTk::Derived Tcl::pTk::Menubutton);
 
+use strict;
+
 Construct Tcl::pTk::Widget 'Optionmenu';
 
 sub Populate
