@@ -1,14 +1,12 @@
 package Tcl::pTk::ProgressBar;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk;
 use Tcl::pTk::Canvas;
 #use Tk::Trace;
 use Carp;
+use strict;
 
 use base qw(Tcl::pTk::Derived Tcl::pTk::Canvas);
 
