@@ -11,10 +11,7 @@
 
 package Tcl::pTk::TextEdit;
 
-our ($VERSION) = ('1.08_02');
-
-use warnings;
-use strict;
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk qw (Ev);
 use AutoLoader;
