@@ -1,6 +1,6 @@
 package Tcl::pTk::Tile;
 
-our ($VERSION) = ('1.08_02');
+our ($VERSION) = ('1.01');
 
 use strict;
 use warnings;
@@ -27,12 +27,10 @@ Tcl::pTk::Tile -  Tile/ttk Widget Support for Tcl::pTk
 
 =head1 DESCRIPTION
 
-I<Tcl::pTk::Tile> provides some helper methods and mappings for Tile/ttk support
-in the L<Tcl::pTk> package. Tile/ttk are the new themed widget set that is
-present in Tcl/Tk 8.5 and above, and available for Tcl/Tk 8.4 in the Tile package.
-
-This package is auto-loaded and the tile widgets declared if Tk 8.5 is being
-used by Tcl::pTk, or if the Tile package for Tk 8.4 is installed.
+I<Tcl::pTk::Tile> provides some helper methods and mappings for Tile/ttk support L<Tcl::pTk> package. Tile/ttk are the
+new themed widget set that is present in Tcl version 8.5 and above.
+        
+This package is auto-loaded and the tile widgets declared if a Tcl version > 8.5 is being used by Tcl::pTk.
 
 =head2 Style method mapping
 
@@ -112,9 +110,8 @@ sub Tcl::pTk::Widget::ttkThemes {
 
 =head2 _declareTileWidgets
 
-Internal sub to declare the tile widgets. This is called when a mainwindow
-is created, if we are using Tcl/Tk 8.5 or higher, or the Tile package for
-Tcl/Tk 8.4 is present.
+Internal sub to declare the tile widgets. This is called when a mainwindow is created, if we are
+using a Tcl version >= 8.5.
 
 B<Usage:>
 
@@ -139,11 +136,7 @@ sub _declareTileWidgets {
 
 		#print STDERR "delcareing "."ttk".ucfirst($ttkwidget).
 		#                 "  ttk::$ttkwidget\n";
-		$interp->Declare(
-			'ttk' . ucfirst($ttkwidget),
-			"ttk::$ttkwidget",
-			-require => 'tile',
-		);
+		$interp->Declare( "ttk" . ucfirst($ttkwidget), "ttk::$ttkwidget", -require => 'Ttk' );
 	}
 
 }
@@ -182,27 +175,12 @@ sub _setupMapping {
 	}
 }
 
-###### Special cases to get ttkTreeview methods to work ###
-
-# Avoid using Tcl::pTk::Widget::children
-sub Tcl::pTk::ttkTreeview::children {
-    my $self = shift;
-    $self->call($self->path, 'children', @_);
-}
-
-# Ensure Perl list (not Tcl list) is returned
-# https://github.com/chrstphrchvz/perl-tcl-ptk/issues/7
-sub Tcl::pTk::ttkTreeview::selection {
-    my $self = shift;
-    $self->call($self->path, 'selection', @_);
-}
-sub Tcl::pTk::ttkTreeview::item {
-    my $self = shift;
-    $self->call($self->path, 'item', @_);
-}
-sub Tcl::pTk::ttkTreeview::tag {
-    my $self = shift;
-    $self->call($self->path, 'tag', @_);
+###### Special cases to get ttkTreeview children method to work ###
+### If this isn't here, the inherited Tcl::pTk::Widget::children will get called, which is not what we 
+### want
+sub Tcl::pTk::ttkTreeview::children{
+        my $self = shift;
+        $self->call($self->path, "children", @_);
 }
 
 1;
