@@ -6,9 +6,8 @@
 
 package Tcl::pTk::Wm;
 
-our ($VERSION) = ('1.08_02');
+our ($VERSION) = ('1.01');
 
-use warnings;
 use strict;
 
 use base qw( Tcl::pTk::Derived );
@@ -20,7 +19,7 @@ Direct Tcl::pTk::Submethods ('wm' => [qw(aspect attributes capture client colorm
                        deiconify focusmodel frame geometry group
                        iconbitmap iconify  iconphoto iconmask iconname
                        iconwindow maxsize minsize overrideredirect positionfrom
-                        release resizable sizefrom stackorder state title transient
+                        release resizable sizefrom state title transient
                        withdraw wrapper )]);
 
 sub SetBindtags
@@ -55,7 +54,7 @@ sub MoveToplevelWindow
 
 # Implementation of the perl/tk 'iconimage' method. 
 # This is translated to an 'iconphoto' call, which is only available
-#  in more recent (>= 8.5) tk's
+#  in more recent (> 8.5) tk's
 sub iconimage{
  my ($w, $photo) = @_;
  $w->interp->icall('wm', 'iconphoto', $w->path, $photo);
