@@ -2,7 +2,7 @@ package WidgetDemo;
 
 use 5.005_03;
 
-our ($VERSION) = ('1.08_02');
+our ($VERSION) = ('1.01');
 
 use Tcl::pTk;
 use Carp;
@@ -28,8 +28,13 @@ sub Populate {
 	-geometry_manager => 'pack',
     );
     
-    # Use Tile Buttons if available
-    my $buttonWidget = $pTk::Tcl::_Tile_available ? 'ttkButton' : 'Button';
+    # Use tile Buttons, if tcl version is >= 8.5
+    my $buttonWidget = 'Button';
+    $buttonWidget = 'ttkButton' if( $self->tclVersion() >= 8.5);
+    
+
+    
+    
     
     my $name = $arg_defaults{-name};
     $arg_defaults{-title} = "$name Demonstration",
